# ¡Empezar!

Bienvenido a Rapunzel, un entorno de desarrollo moderno para Python y R. Aquí tienes algunos atajos de teclado útiles.

## Trabajando con carpetas y archivos de proyecto

- [`Ctrl+Shift+O`: Abrir carpeta de proyecto](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Abrir archivo de las carpetas del proyecto](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Crear documento vacío](opensesame://event.ide_new_file)

## Haciendo cosas rápidamente

- [`Ctrl+Shift+P`: Activar paleta de comandos](opensesame://event.command_palette_activate)
- `Ctrl+R`: Saltar a función o clase

## Ejecutando código

- `F5`: Ejecutar proyecto o archivo
- `F9`: Ejecutar selección, celda o línea actual